Struct openssl::rsa::RsaRef [−][src]
pub struct RsaRef<T>(_, _);Expand description
Reference to RSA
Implementations
Serializes the private key to a PEM-encoded PKCS#1 RSAPrivateKey structure.
The output will have a header of -----BEGIN RSA PRIVATE KEY-----.
This corresponds to PEM_write_bio_RSAPrivateKey.
pub fn private_key_to_pem_passphrase(
&self,
cipher: Cipher,
passphrase: &[u8]
) -> Result<Vec<u8>, ErrorStack>
pub fn private_key_to_pem_passphrase(
&self,
cipher: Cipher,
passphrase: &[u8]
) -> Result<Vec<u8>, ErrorStack>
Serializes the private key to a PEM-encoded encrypted PKCS#1 RSAPrivateKey structure.
The output will have a header of -----BEGIN RSA PRIVATE KEY-----.
This corresponds to PEM_write_bio_RSAPrivateKey.
Serializes the private key to a DER-encoded PKCS#1 RSAPrivateKey structure.
This corresponds to i2d_RSAPrivateKey.
Decrypts data using the private key, returning the number of decrypted bytes.
Panics
Panics if self has no private components, or if to is smaller
than self.size().
Encrypts data using the private key, returning the number of encrypted bytes.
Panics
Panics if self has no private components, or if to is smaller
than self.size().
Returns a reference to the private exponent of the key.
This corresponds to RSA_get0_key.
Returns a reference to the first factor of the exponent of the key.
This corresponds to RSA_get0_factors.
Returns a reference to the second factor of the exponent of the key.
This corresponds to RSA_get0_factors.
Returns a reference to the first exponent used for CRT calculations.
This corresponds to RSA_get0_crt_params.
Returns a reference to the second exponent used for CRT calculations.
This corresponds to RSA_get0_crt_params.
Returns a reference to the coefficient used for CRT calculations.
This corresponds to RSA_get0_crt_params.
Validates RSA parameters for correctness
This corresponds to RSA_check_key.
Serializes the public key into a PEM-encoded SubjectPublicKeyInfo structure.
The output will have a header of -----BEGIN PUBLIC KEY-----.
This corresponds to PEM_write_bio_RSA_PUBKEY.
Serializes the public key into a DER-encoded SubjectPublicKeyInfo structure.
This corresponds to i2d_RSA_PUBKEY.
Serializes the public key into a PEM-encoded PKCS#1 RSAPublicKey structure.
The output will have a header of -----BEGIN RSA PUBLIC KEY-----.
This corresponds to PEM_write_bio_RSAPublicKey.
Serializes the public key into a DER-encoded PKCS#1 RSAPublicKey structure.
This corresponds to i2d_RSAPublicKey.
Returns the size of the modulus in bytes.
This corresponds to RSA_size.
Decrypts data using the public key, returning the number of decrypted bytes.
Panics
Panics if to is smaller than self.size().
Encrypts data using the public key, returning the number of encrypted bytes.
Panics
Panics if to is smaller than self.size().
Returns a reference to the modulus of the key.
This corresponds to RSA_get0_key.
Returns a reference to the public exponent of the key.
This corresponds to RSA_get0_key.